"use strict";
/*
    This is a custom hook which takes care of handling the input.

    It takes three things as props:
        - maxLength: the max length of the input provided by user
        - onPress: the callback function provided by user to be called when the key is pressed
        - onSubmitPress: the callback provided by user function to be called when the submit button is pressed

    It returns three values:
        - `onKeyPress`: callback function to be called when the key is pressed.
        - `onBackSpacePress`: callback function to be called when the backspace key is pressed.
        - `onSubmit`: callback function to be called when the submit button is pressed.

*/
Object.defineProperty(exports, "__esModule", { value: true });
// Packages imports
var react_1 = require("react");
// Hooks imports
function useTextManager(_a) {
    var maxLength = _a.maxLength, onPress = _a.onPress, onSubmitPress = _a.onSubmitPress;
    // Local Variable for the input value
    var OTP = react_1.useRef("");
    // Callback fired on press of a key
    var onKeyPress = function (text) {
        try {
            if (maxLength && OTP.current.length >= maxLength)
                return;
            if (text) {
                OTP.current = OTP.current + text;
                if (typeof onPress === "function")
                    onPress(OTP.current);
            }
        }
        catch (error) { }
    };
    // Callback fired on backspace press
    var onBackSpacePress = function () {
        try {
            OTP.current = OTP.current.slice(0, -1);
            if (typeof onPress === "function")
                onPress(OTP.current);
        }
        catch (error) { }
    };
    // Callback fired on submit press
    var onSubmit = function () {
        try {
            if (typeof onSubmitPress === "function")
                onSubmitPress(OTP.current);
        }
        catch (error) { }
    };
    // Exporting the callbacks here
    return {
        onKeyPress: onKeyPress,
        onBackSpacePress: onBackSpacePress,
        onSubmit: onSubmit
    };
}
exports.default = useTextManager;
//# sourceMappingURL=useTextManager.js.map